#/bin/bash

source settings.sh

echo "Increasing system.img size"
dd if=/dev/zero count=4 bs=256M >> $SYS_IMG_FILE

echo "Mounting system.img"
mkdir -p $SYSROOT_DIR
sudo mount $SYS_IMG_FILE $SYSROOT_DIR

echo "Resizing mounted system.img filesystem"
FULL_SYSROOT_DIR=$(realpath $SYSROOT_DIR)
SYSROOT_MOUNT_DEVICE=$(df | grep $FULL_SYSROOT_DIR | awk '{print $1}')
sudo resize2fs $SYSROOT_MOUNT_DEVICE

echo "Preparing system libraries for Qt"
sudo cp $SYSROOT_DIR/usr/lib/libGLESv2.so.2 $SYSROOT_DIR/usr/lib/libGLESv2.so

echo "Downloading g++"
sudo apt-get install g++ -y

echo "Downloading QtCreator"
sudo apt-get install qtcreator -y

echo "Downloading arm-linux-gnueabi cross compiler with GCC 4.9.4"
mkdir -p $TEMP_DIR
wget -O $TEMP_DIR/gcc-linaro-4.9.4-2017.01-x86_64_arm-linux-gnueabi.tar.xz -c "https://releases.linaro.org/components/toolchain/binaries/4.9-2017.01/arm-linux-gnueabi/gcc-linaro-4.9.4-2017.01-x86_64_arm-linux-gnueabi.tar.xz"

echo "Extracting arm-linux-gnueabi cross compiler"
sudo tar -xf $TEMP_DIR/gcc-linaro-4.9.4-2017.01-x86_64_arm-linux-gnueabi.tar.xz -C $COMPILER_DIR

echo "Downloading Qt 5.7.1"
wget -O $TEMP_DIR/qt-everywhere-opensource-src-5.7.1.tar.xz -c https://download.qt.io/new_archive/qt/5.7/5.7.1/single/qt-everywhere-opensource-src-5.7.1.tar.xz

echo "Extracting Qt"
sudo tar -xf $TEMP_DIR/qt-everywhere-opensource-src-5.7.1.tar.xz -C $TEMP_DIR


COMPILER_DIR_FULL_PATH=$(realpath $COMPILER_DIR)
COMPILER_DIR_FULL_PATH=$COMPILER_DIR_FULL_PATH/gcc-linaro-4.9.4-2017.01-x86_64_arm-linux-gnueabi
SYSROOT_DIR_FULL_PATH=$(realpath $SYSROOT_DIR)

echo "Compiling Qt"
ORIGINAL_PATH=$(realpath .)
cd $TEMP_DIR/qt-everywhere-opensource-src-5.7.1
./configure -device arm-generic-g++ -device-option CROSS_COMPILE=$COMPILER_DIR_FULL_PATH/bin/arm-linux-gnueabi- -opensource -confirm-license -sysroot $SYSROOT_DIR_FULL_PATH -skip declarative -nomake examples -skip virtualkeyboard 

echo "Starting Qt compile, this may take a few minutes"
sudo gmake -j4

echo "Installing Qt"
sudo gmake install 

cd $ORIGINAL_PATH

echo "Performing Cleanup"
sudo rm -rf $TEMP_DIR

echo "Completed D-Audio 2 Development Environment Setup. Start QtCreator and follow the last steps of the tutorial to register the kit and compiler."